@@ -1,10 +1,10 @@
 ##----------------------------------------------------------------------------
 ## Module Generic - ~/lib/Module/Generic/Number.pm
-## Version v2.3.0
+## Version v2.3.1
 ## Copyright(c) 2025 DEGUEST Pte. Ltd.
 ## Author: Jacques Deguest <jack@deguest.jp>
 ## Created 2021/03/20
-## Modified 2025/04/19
+## Modified 2025/04/20
 ## All rights reserved
 ## 
 ## This program is free software; you can redistribute  it  and/or  modify  it
@@ -109,9 +109,11 @@ BEGIN
     if( HAS_THREADS )
     {
         require threads;
-        import threads;
+        require threads::shared;
+        threads->import();
+        threads::shared->import();
     }
-    our( $VERSION ) = 'v2.3.0';
+    our( $VERSION ) = 'v2.3.1';
 };
 
 use v5.26.1;
